@@ -46,4 +46,19 @@ def test_unicode():
     root = sg.root()
     node = root.find(pattern="console.log($A)")
     assert node is not None
-    assert node.range().start.index == 5
\ No newline at end of file
+    assert node.range().start.index == 5
+    assert node.range().start.line == 0
+    assert node.range().start.column == 5
+
+def test_unicode_range_rule():
+    source = "ハロ = console.log(世界)".strip()
+    sg = SgRoot(source, "javascript")
+    root = sg.root()
+    node = root.find(range={"start": {"row": 0, "column": 17}, "end": {"row": 0, "column": 19}})
+    assert node
+    assert node.range().start.index == 17
+    assert node.range().start.line == 0
+    assert node.range().start.column == 17
+    assert node.range().end.index == 19
+    assert node.range().end.line == 0
+    assert node.range().end.column == 19
\ No newline at end of file
